% ---------------------------------
% author  : latexstudio
% website : www.latexstudio.net
% time    : 2022-01-04 10:26:39
% e-mail  : typeset@latexstudio.net
% ---------------------------------

\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{JUSTC}[2021/01/04, v1.0 by latexstudio.net]


\newif\if@linenumberon\global\@linenumberonfalse%
\DeclareOption{lineno}{\global\@linenumberontrue}%
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[10pt,twoside,a4paper]{article}

\RequirePackage{geometry}

\geometry{
  paperwidth  = 155mm,
  paperheight = 235mm,
  text        = {119mm,190mm},
  right       = 18mm,
  top         = 20mm,
  headsep     = \baselineskip
}

\RequirePackage[numbers,sort&compress]{natbib}
\RequirePackage{xcolor}
\RequirePackage{
  expl3    , newtxtext , graphicx , url      ,
  xpatch   , caption   , etoolbox , subfig   ,
  booktabs , array     , makecell , enumitem ,
  lipsum   , listings  , fancyhdr , bm       ,
  amsmath  , amssymb   , amsthm   ,
  siunitx  , endfloat
}

\if@linenumberon%
\RequirePackage[mathlines,running]{lineno}
\let\linenumbershook\linenumbers
\else
\let\linenumbershook\empty
\fi%

\urlstyle{same}
\lstset{breaklines=true,basicstyle=\small\ttfamily}

\def\etal{\textit{et al}.}
\sisetup{group-separator={\,},group-minimum-digits=4,separate-uncertainty=true}
\graphicspath{{res/},{figs/}}
\bibsep 2pt

\setlist{nosep}
\setlist[enumerate,1]{label=(\arabic*)}

\ExplSyntaxOn

\keys_define:nn { JUSTCkeys } {
  name          . tl_set:N    = \l_JUSTCkeys_name_tl,
  name          . initial:n   = JUSTC,
  abbname       . tl_set:N    = \l_JUSTCkeys_abbname_tl,
  abbname       . initial:n   = JUSTC,
  type          . tl_set:N    = \l_JUSTCkeys_type_tl,
  type          . initial:n   = Manuscript~type,
  abstract      . tl_set:N    = \l_JUSTCkeys_abstract_tl,
  abstract      . initial:n   = abstract~content,
  GraphicalAbstract . tl_set:N  = \l_JUSTCkeys_GraphicalAbstract_tl,
  GraphicalAbstract . initial:n = GraphicalAbstract~content,
  keywords      . tl_set:N    = \l_JUSTCkeys_keywords_tl,
  keywords      . initial:n   = keywords~content,
  title         . tl_set:N    = \l_JUSTCkeys_title_tl,
  title         . initial:n   = title~content,
  author        . clist_set:N = \l_JUSTCkeys_author_clist,
  corrauthor    . clist_set:N = \l_JUSTCkeys_corrauthor_clist,
  ausuper       . clist_set:N = \l_JUSTCkeys_ausuper_clist,
  address       . clist_set:N = \l_JUSTCkeys_address_clist,
  email         . clist_set:N = \l_JUSTCkeys_email_clist,
  runningauthor . tl_set:N    = \l_JUSTCkeys_runningauthor_tl,
  runningauthor . initial:n   = runningauthor~content,
  runningtitle  . tl_set:N    = \l_JUSTCkeys_runningtitle_tl,
  runningtitle  . initial:n   = runningtitle~content,
  copyright     . tl_set:N    = \l_JUSTCkeys_copyright_tl,
  copyright     . initial:n   = {\textcopyright\ Operations Research Society of China, Periodicals Agency of Shanghai University, Science Press, and Springer-Verlag GmbH Germany, part of Springer Nature 2022},
}

\linespread{1.5}

\fancypagestyle{plain}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{.4pt}
  \fancyhead[L]{\sffamily\l_JUSTCkeys_name_tl}
  \fancyhead[R]{\sffamily\l_JUSTCkeys_type_tl}
}

\fancypagestyle{main}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{.4pt}
  \fancyhead[L]{\sffamily\l_JUSTCkeys_abbname_tl}
  \fancyhead[R]{\sffamily\l_JUSTCkeys_runningauthor_tl}
  \fancyhead[C]{\sffamily\l_JUSTCkeys_runningtitle_tl}
  \fancyfoot[R]{\sffamily\small\thepage}
}

\tl_new:N \l_JUSTCkeys_options_tl

\DeclareDocumentCommand\type{m}{\tl_set:Nn \l_JUSTCkeys_type_tl {#1}}
\DeclareDocumentCommand\title{m}{\tl_set:Nn \l_JUSTCkeys_title_tl {#1}}
\DeclareDocumentCommand\runningtitle{m}{\tl_set:Nn \l_JUSTCkeys_runningtitle_tl {#1}}
\DeclareDocumentCommand\runningauthor{m}{\tl_set:Nn \l_JUSTCkeys_runningauthor_tl {#1}}
\DeclareDocumentCommand\abstract{m}{\tl_set:Nn \l_JUSTCkeys_abstract_tl {#1}}
\DeclareDocumentCommand\GraphicalAbstract{O{}m}{\tl_set:Nn \l_JUSTCkeys_GraphicalAbstract_tl {#2}
\tl_set:Nn \l_JUSTCkeys_options_tl {#1}}
\DeclareDocumentCommand\keywords{m}{\tl_set:Nn \l_JUSTCkeys_keywords_tl {#1}}
\DeclareDocumentCommand\email{m}{\clist_gput_right:Nn \l_JUSTCkeys_email_clist {{#1}}}
\DeclareDocumentCommand\address{m}{\clist_gput_right:Nn \l_JUSTCkeys_address_clist {{#1}}}

\DeclareDocumentCommand\author{O{\@empty}m}{
  \clist_gput_right:Nn \l_JUSTCkeys_ausuper_clist {{#1}}
  \clist_gput_right:Nn \l_JUSTCkeys_author_clist {{#2}}
  \tl_if_in:nnT {#1}{*}{
    \clist_gput_right:Nn \l_JUSTCkeys_corrauthor_clist {{#2}}
  }
}

\tl_new:N \l__author_super_tl
\int_new:N \l_address_num_int
\int_new:N \l_author_num_int
\int_new:N \l_contribute_num_int
\int_new:N \l_author_corr_int
\bool_new:N \l_contribute_num_geq_one_bool

\DeclareDocumentCommand\maketitle{}{
  \pagestyle{main}
  \renewcommand\@makefntext[1]{%
      \parindent 1em%
      \noindent
      \hb@xt@1.8em{\hss\@makefnmark\ }##1}
  \linenumbershook
  \thispagestyle{plain}
  \parindent 0pt
  {\sffamily\bfseries \Large \l_JUSTCkeys_title_tl} \par \bigskip
  \int_gset:Nn \l_author_num_int {\clist_count:N \l_JUSTCkeys_author_clist}
  % %% -- author
  \begingroup\nohyphen \raggedright
  \int_step_inline:nn {\l_author_num_int}{
    \clist_item:Nn \l_JUSTCkeys_author_clist {##1}
    \@textsuperscript{\selectfont
      \clist_item:Nn \l_JUSTCkeys_ausuper_clist {##1}
    }
    \int_compare:nNnF {##1}={\l_author_num_int}{,\ }
  }\par \bigskip
  \endgroup
  % %% -- end author
  \begingroup
  % % -- address
  \int_gset:Nn \l_address_num_int {\clist_count:N \l_JUSTCkeys_address_clist}
  \int_step_inline:nn {\l_address_num_int}{
    \textsuperscript{##1}\ {\clist_item:Nn \l_JUSTCkeys_address_clist {##1}}\par
  }
  % %% -- end address
  % %% -- corresponding author
  \int_gset:Nn \l_author_corr_int {\clist_count:N \l_JUSTCkeys_corrauthor_clist}
  \int_step_inline:nn {\l_author_corr_int}{
      \int_step_inline:nn {##1}{*}{
        \tl_set:Nx \l_tmpa_tl {\clist_item:Nn \l_JUSTCkeys_email_clist {##1}}
        Corresponding~Author(s):\
        \clist_item:Nn \l_JUSTCkeys_corrauthor_clist {##1},~
        \tl_if_empty:NTF \l_tmpa_tl {E-mail~##1~Address}{\l_tmpa_tl}
      }\par
  }
  % %% -- end corresponding author
  \endgroup
  \par \bigskip
  {\sffamily\bfseries Graphical~abstract~\l_JUSTCkeys_options_tl} \par \l_JUSTCkeys_GraphicalAbstract_tl
  \par \bigskip
  {\sffamily\bfseries Abstract} \par \l_JUSTCkeys_abstract_tl
  \par \bigskip
  \def\sep{\ ·\ \ }
  {\sffamily\bfseries Keywords} \par \l_JUSTCkeys_keywords_tl
  \par
  \parindent 1em
}

\ExplSyntaxOff

% ==== sectioning
\def\@seccntformat#1{\csname the#1\endcsname\hskip.5em}
\def\nohyphen{\pretolerance=\@M \tolerance=\@M \hyphenpenalty=\@M \exhyphenpenalty=\@M}
\renewcommand\section{\@startsection{section}{1}{\z@}%
    {-\bigskipamount}%
    {\medskipamount}%
    {\fontsize{11}{12.5}\bfseries\sffamily\mathversion{bold}\raggedright\nohyphen}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
    {-\medskipamount}%
    {\medskipamount}%
    {\fontsize{10}{12.5}\bfseries\sffamily\mathversion{bold}\itshape\raggedright\nohyphen}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
    {-\medskipamount}%
    {\medskipamount}%
    {\fontsize{10}{12.5}\bfseries\sffamily\raggedright}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
    {\medskipamount}%
    {-10pt}%
    {\bfseries\mathversion{bold}}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
    {0.1pt}%
    {-1em}%
    {\itshape}}

\theoremstyle{definition}%
\newtheorem{theorem}{Theorem}% meant for continuous numbers
\newtheorem{proposition}{Proposition}
\newtheorem{remark}{Remark}%
\newtheorem{example}{Example}
\newtheorem{definition}{Definition}%

\RenewDocumentCommand\appendix{}{
  \setcounter{section}{0}
  \setcounter{equation}{0}
  \gdef\thesection{\@Alph\c@section}%
  \gdef\theequation{\@Alph\c@section\arabic{equation}}%
}

\def\UrlBreaks{%
    \do\/%
    \do\a\do\b\do\c\do\d\do\e\do\f\do\g\do\h\do\i\do\j\do\k\do\l%
    \do\m\do\n\do\o\do\p\do\q\do\r\do\s\do\t\do\u\do\v\do\w\do\x\do\y\do\z%
    \do\A\do\B\do\C\do\D\do\E\do\F\do\G\do\H\do\I\do\J\do\K\do\L%
    \do\M\do\N\do\O\do\P\do\Q\do\R\do\S\do\T\do\U\do\V\do\W\do\X\do\Y\do\Z%
    \do0\do1\do2\do3\do4\do5\do6\do7\do8\do9\do=\do/\do.\do:%
    \do\*\do\-\do\~\do\'\do\"\do\-}
\Urlmuskip=0mu plus 0.1mu

\AtEndPreamble{
  \RequirePackage{hyperref}
  \hypersetup{
    hidelinks,
    CJKbookmarks       = true,
    bookmarksnumbered  = true,
    bookmarksopen      = true,
    bookmarksopenlevel = 2,
    unicode            = true,
    colorlinks         = false,
    breaklinks         = false,
  }
}

\endinput

%%

